BaseStationBluetoothCharacteristics class

Constructors

BaseStationBluetoothCharacteristics({required BluetoothCharacteristic raceFullState, required BluetoothCharacteristic control, required BluetoothCharacteristic settings})

Properties

control → BluetoothCharacteristic
final
hashCode int
The hash code for this object.
no setterinherited
onRaceState Stream<RaceFullState>
no setter
onSettings Stream<Settings>
no setter
raceFullState → BluetoothCharacteristic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings → BluetoothCharacteristic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCommand(Command command) Future<void>
sendSettings(Settings settings) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited