BluetoothConnection class

Inheritance

Constructors

BluetoothConnection.init()

Properties

baseStationConnectionState BaseStationConnectionEnum
no setter
baseStationConnectionStateStream Stream<BaseStationConnectionEnum>
no setter
bluetoothState ↔ BluetoothAdapterState
getter/setter pair
characteristics BaseStationBluetoothCharacteristics
getter/setter pair
device ↔ BluetoothDevice
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
onRaceState Stream<RaceFullState>
no setteroverride
onSettings Stream<Settings>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service ↔ BluetoothService
getter/setter pair

Methods

connect(BluetoothDevice device) Future<void>
override
disconnect() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(dynamic onScanResult(List<ScanResult>)) → void
override
sendCommand(Command command) Future<void>
override
sendSettings(Settings settings) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited