BaseStationConnection class abstract

Implementers

Constructors

BaseStationConnection()

Properties

hashCode int
The hash code for this object.
no setterinherited
onRaceState Stream<RaceFullState>
no setter
onSettings Stream<Settings>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(BluetoothDevice device) Future<void>
disconnect() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(dynamic onScanResult(List<ScanResult>)) → void
sendCommand(Command command) Future<void>
sendSettings(Settings settings) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited