LaneTimer class

Constructors

LaneTimer()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
no setter
logger → Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
start(dynamic callback(Duration), [int updateInterval = 100]) → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited