reactionTime property

  1. @TagNumber.new(2)
int get reactionTime

The reaction time in milliseconds relative to the beginning of the start sequence. To get the common representation of the reaction time (relative to the beginning of the third beep), 3000ms must be subtracted. If this is 0, the reaction time is not set (yet).

Implementation

@$pb.TagNumber(2)
$core.int get reactionTime => $_getIZ(1);
  1. @TagNumber.new(2)
set reactionTime (int v)

Implementation

@$pb.TagNumber(2)
set reactionTime($core.int v) { $_setUnsignedInt32(1, v); }