autoReset property
If set to true, the autostart will be executed even if the race is not in IDLE_CLEAR_TO_START state.
Implementation
@$pb.TagNumber(3)
$core.bool get autoReset => $_getBF(2);
Implementation
@$pb.TagNumber(3)
set autoReset($core.bool v) { $_setBool(2, v); }