continueStartSequenceAfterFalseStart property
If set to true, there will be no false start tone and the normal tone will continue. Also, the indicator of wildcard lanes will continue as normal.
Implementation
@$pb.TagNumber(2)
$core.bool get continueStartSequenceAfterFalseStart => $_getBF(1);
Implementation
@$pb.TagNumber(2)
set continueStartSequenceAfterFalseStart($core.bool v) { $_setBool(1, v); }