disableBluetooth property

  1. @TagNumber.new(1)
bool get disableBluetooth

If set to true, the bluetooth interface won't be initialized on startup. This can only be changed over a web socket connection to avoid lockout. To be effective, the settings must be stored as default and device must be rebooted!

Implementation

@$pb.TagNumber(1)
$core.bool get disableBluetooth => $_getBF(0);
  1. @TagNumber.new(1)
set disableBluetooth (bool v)

Implementation

@$pb.TagNumber(1)
set disableBluetooth($core.bool v) { $_setBool(0, v); }