muteInternalSpeaker property

  1. @TagNumber.new(2)
bool get muteInternalSpeaker

If set to true, the internal speaker will be muted. This is useful if the device is connected to an external speaker. Supported from version 1.1.0 onwards.

Implementation

@$pb.TagNumber(2)
$core.bool get muteInternalSpeaker => $_getBF(1);
  1. @TagNumber.new(2)
set muteInternalSpeaker (bool v)

Implementation

@$pb.TagNumber(2)
set muteInternalSpeaker($core.bool v) { $_setBool(1, v); }