UILaneState class

Constructors

UILaneState({required int laneIndex, LaneFullState? laneFullState})

Properties

availableLaneActions int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
laneFullState LaneFullState?
getter/setter pair
laneIndex int
getter/setter pair
laneSubtext String?
getter/setter pair
laneTextColor Color
getter/setter pair
laneTextTime List<TextSpan>
getter/setter pair
onDisableLanePressed ↔ void Function()?
getter/setter pair
onEnableLanePressed ↔ void Function()?
getter/setter pair
onFallPressed ↔ void Function()?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited