UIState class

Constructors

UIState()

Properties

autostartProgress double?
getter/setter pair
availableRaceActions int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
laneStates List<UILaneState>
getter/setter pair
onAtYourMarksPressed ↔ void Function()?
getter/setter pair
onMutePressed ↔ void Function()?
getter/setter pair
onReadyPressed ↔ void Function()?
getter/setter pair
onResetPressed ↔ void Function()?
getter/setter pair
raceState RaceFullState_State
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Settings
getter/setter pair
stopwatchDuration Duration?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited