UIStateController class

Constructors

UIStateController(BaseStationConnection _connection)

Properties

hashCode int
The hash code for this object.
no setterinherited
lastUIState UIState
getter/setter pair
logger → Logger
final
raceResultsStream Stream<List<UILaneState>>
no setter
raceResultStreamController StreamController<List<UILaneState>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uiStateStream Stream<UIState>
no setter
version → dynamic
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited