timeIsCalculated property
If this is true, the time is calculated and the valid.
This happens when the athlete does a false start but still finishes.
In this case, the client should mark the time as invalid.
Implementation
@$pb.TagNumber(2)
$core.bool get timeIsCalculated => $_getBF(1);
Implementation
@$pb.TagNumber(2)
set timeIsCalculated($core.bool v) { $_setBool(1, v); }