autoReset property

  1. @TagNumber.new(3)
bool get autoReset

If set to true, the autostart will be executed even if the race is not in IDLE_CLEAR_TO_START state.

Implementation

@$pb.TagNumber(3)
$core.bool get autoReset => $_getBF(2);
  1. @TagNumber.new(3)
set autoReset (bool v)

Implementation

@$pb.TagNumber(3)
set autoReset($core.bool v) { $_setBool(2, v); }