turnOffWhenFalseStartSoundIsMuted property
If set to true, the indicator will stop blinkng as soon as the false start sound stops (when a false start exists and race is in FINISHED_MUTED state). Otherwise, it will continue blinking until the race is reset.
Implementation
@$pb.TagNumber(2)
$core.bool get turnOffWhenFalseStartSoundIsMuted => $_getBF(1);
Implementation
@$pb.TagNumber(2)
set turnOffWhenFalseStartSoundIsMuted($core.bool v) { $_setBool(1, v); }