disableBluetooth property
If set to true, the bluetooth interface won't be initialized on startup. This can only be changed over a web socket connection to avoid lockout. To be effective, the settings must be stored as default and device must be rebooted!
Implementation
@$pb.TagNumber(1)
$core.bool get disableBluetooth => $_getBF(0);
Implementation
@$pb.TagNumber(1)
set disableBluetooth($core.bool v) { $_setBool(0, v); }